@@ -1,4 +1,4 @@
-from typing import TYPE_CHECKING, Any, Dict, List, Optional, Union, cast
+from typing import TYPE_CHECKING, Any, Dict, List, Optional, Sequence, Union, cast
 
 from cognite.client import utils
 from cognite.client.data_classes._base import (
@@ -33,7 +33,7 @@ class TimeSeries(CogniteResource):
         asset_id (int): Asset ID of equipment linked to this time series.
         is_step (bool): Whether the time series is a step series or not.
         description (str): Description of the time series.
-        security_categories (List[int]): The required security categories to access this time series.
+        security_categories (Sequence[int]): The required security categories to access this time series.
         data_set_id (int): The dataSet Id for the item.
         created_time (int): The number of milliseconds since 00:00:00 Thursday, 1 January 1970, Coordinated Universal Time (UTC), minus leap seconds.
         last_updated_time (int): The number of milliseconds since 00:00:00 Thursday, 1 January 1970, Coordinated Universal Time (UTC), minus leap seconds.
@@ -52,7 +52,7 @@ class TimeSeries(CogniteResource):
         asset_id: int = None,
         is_step: bool = None,
         description: str = None,
-        security_categories: List[int] = None,
+        security_categories: Sequence[int] = None,
         data_set_id: int = None,
         created_time: int = None,
         last_updated_time: int = None,
@@ -159,10 +159,10 @@ class TimeSeriesFilter(CogniteFilter):
         is_string (bool): Filter on isString.
         is_step (bool): Filter on isStep.
         metadata (Dict[str, str]): Custom, application specific metadata. String key -> String value. Limits: Maximum length of key is 32 bytes, value 512 bytes, up to 16 key-value pairs.
-        asset_ids (List[int]): Only include time series that reference these specific asset IDs.
-        asset_external_ids (List[str]): Asset External IDs of related equipment that this time series relates to.
-        asset_subtree_ids (List[Dict[str, Any]]): Only include time series that are related to an asset in a subtree rooted at any of these assetIds (including the roots given). If the total size of the given subtrees exceeds 100,000 assets, an error will be returned.
-        data_set_ids (List[Dict[str, Any]]): No description.
+        asset_ids (Sequence[int]): Only include time series that reference these specific asset IDs.
+        asset_external_ids (Sequence[str]): Asset External IDs of related equipment that this time series relates to.
+        asset_subtree_ids (Sequence[Dict[str, Any]]): Only include time series that are related to an asset in a subtree rooted at any of these assetIds (including the roots given). If the total size of the given subtrees exceeds 100,000 assets, an error will be returned.
+        data_set_ids (Sequence[Dict[str, Any]]): No description.
         external_id_prefix (str): Filter by this (case-sensitive) prefix for the external ID.
         created_time (Union[Dict[str, Any], TimestampRange]): Range between two timestamps.
         last_updated_time (Union[Dict[str, Any], TimestampRange]): Range between two timestamps.
@@ -176,10 +176,10 @@ class TimeSeriesFilter(CogniteFilter):
         is_string: bool = None,
         is_step: bool = None,
         metadata: Dict[str, str] = None,
-        asset_ids: List[int] = None,
-        asset_external_ids: List[str] = None,
-        asset_subtree_ids: List[Dict[str, Any]] = None,
-        data_set_ids: List[Dict[str, Any]] = None,
+        asset_ids: Sequence[int] = None,
+        asset_external_ids: Sequence[str] = None,
+        asset_subtree_ids: Sequence[Dict[str, Any]] = None,
+        data_set_ids: Sequence[Dict[str, Any]] = None,
         external_id_prefix: str = None,
         created_time: Union[Dict[str, Any], TimestampRange] = None,
         last_updated_time: Union[Dict[str, Any], TimestampRange] = None,
